TableNd

Struct TableNd 

pub struct TableNd<T, const N: usize> { /* private fields */ }
A dense N-dimensional table.

Implementations

Source

impl<T: Default + Clone, const N: usize> TableNd<T, N>

pub fn new(size: [usize; N]) -> Self

Creates a new dense table initialized with default values.

Source

impl<T: Clone, const N: usize> TableNd<T, N>

pub fn init(value: T, size: [usize; N]) -> Self

Creates a new dense table initialized with the given value.

pub fn fill(&mut self, value: T)

Fills the table with the given value.

Source

impl<T, const N: usize> TableNd<T, N>

pub fn size(&self) -> &[usize; N]

Returns the multi-dimensional size of this table.

Source

impl<T, const N: usize> TableNd<Option<T>, N>

pub fn capacity(&self) -> usize

Returns the capacity of this table, i.e. the total number of memory slots available.

This is the product of the size().

pub fn len(&self) -> usize

Returns the number of values set to Some(_).

pub fn is_empty(&self) -> bool

Checks if all the values are set to None.